@@ -1,5 +1,8 @@
 import os
 
+app_path = r"d:/FastCNN/"
+data_path = r"e:/FastCNN/"
+
 class PathProxy:
     """
     path define here
@@ -9,6 +12,9 @@ class PathProxy:
     def getConfigPath():
         return PathProxy.app_path + r"Config\Config.json"
     
+    def getWeightsPath():
+        return os.path.join(PathProxy.app_path,"Config","weights")
+    
     def getProjectDir(projectname):
         return os.path.join(PathProxy.project_path , projectname )+"\\"
     
@@ -64,6 +70,9 @@ class PathProxy2:
     def getConfigPath(projectid,modelid):
         return os.path.join(PathProxy2.app_path,"Projects",projectid,modelid, "Config.json")
     
+    def getWeightsPath():
+        return os.path.join(PathProxy.app_path,"Config","weights")
+    
     def getDatasetRecordPath(projectid,modelid):
         return os.path.join(PathProxy2.app_path,"Projects",projectid,modelid, "Dataset.csv")
     
@@ -106,6 +115,64 @@ class PathProxy2:
             return
         os.makedirs(dir)
         pass
+        
+class PathProxy3:
+    """
+    path define here
+    """
+    
+    
+    def getConfigPath(projectid,modelid):
+        return os.path.join(app_path,"Projects",projectid,modelid, "Config.json")
+    
+    def getModelDir(projectid,modelid):
+        return os.path.join(app_path,"Projects",projectid,modelid)
+    
+    def getDatasetRecordPath(projectid,modelid):
+        return os.path.join(app_path,"Projects",projectid,modelid, "Dataset.csv")
+    
+    def getWeightsPath():
+        return os.path.join(app_path,"Config","weights")
+    
+    def getSuperParamConfigPath(projectid,modelid):
+        return os.path.join(app_path,"Projects",projectid,modelid, "SuperParam.json")
+    
+    def getTrainProcessValues(projectid,modelid):
+        return os.path.join(app_path,"Projects",projectid,modelid,"tpv.csv")
+    
+    def getSaverIndex(projectid,modelid):
+        return os.path.join(app_path,"Projects",projectid,modelid,"saver.index")
+    
+    def getTrainCKPT(projectid,modelid):
+        return os.path.join(app_path,"Projects",projectid,modelid,"TrainSaver", "save.pth")
+    
+    def getTrainCKPTPath(projectid,modelid):
+        return os.path.join(app_path,"Projects",projectid,modelid,"TrainSaver","model.epoch")
+    
+    def getValidCKPT(projectid,modelid):
+        return os.path.join(app_path,"Projects",projectid,modelid,"ValidSaver", "save.pth")
+    
+    def getValidCKPTPath(projectid,modelid):
+        return os.path.join(app_path,"Projects",projectid,modelid,"ValidSaver","model.epoch")
+    
+    def getProjectNames():
+        return os.listdir(os.path.join(app_path,"Projects"))
+    
+    def getProjectTags(projectname):
+        return os.listdir(os.path.join(project_path,projectname,"models"))
+    
+    
+    def getSaverPath(projectname,tag):
+        return os.path.join(getModelTagDir(projectname,tag) , "ckpt")
+    
+    """
+    method here
+    """
+    def mkdir(dir):
+        if os.path.exists(dir):
+            return
+        os.makedirs(dir)
+        pass
     
 if __name__ == "__main__":
     cp = PathProxy2.getConfigPath("New Project1","20210713_122853")
